# Generated by roxygen2: do not edit by hand

export(cleanup_sandbox)
export(find_root)
export(run_in_sandbox)
export(setup_sandbox)
export(snapshot)
export(with_example)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(stats,lm)
importFrom(utils,getSrcref)
importFrom(utils,str)
importFrom(yaml,read_yaml)
