% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sandbox.R
\name{cleanup_sandbox}
\alias{cleanup_sandbox}
\title{Clean Up a Sandbox Environment}
\usage{
cleanup_sandbox(sandbox = NULL, force = TRUE)
}
\arguments{
\item{sandbox}{Optional. A sandbox object created by \code{setup_sandbox()}.
If NULL (default), cleans up the most recently created sandbox.}

\item{force}{Logical. If TRUE (default), removes directory even if it
contains files.}
}
\value{
Logical indicating success (invisible).
}
\description{
Removes a sandbox directory and all its contents. This should be called
after testing is complete to free up disk space.
}
\examples{
with_example({
  sandbox <- setup_sandbox()
  cleanup_sandbox(sandbox)
})
}
