% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/snapshot.R
\name{get_start_path_for_find_root}
\alias{get_start_path_for_find_root}
\title{Get start path for find_root}
\usage{
get_start_path_for_find_root()
}
\value{
Character path to start searching from
}
\description{
Helper function to determine the starting path for find_root().
Checks for stored sandbox WD first, then falls back to getwd().
}
\keyword{internal}
