% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internal.R
\name{.reset_last_sandbox}
\alias{.reset_last_sandbox}
\title{Reset sandbox state (internal)}
\usage{
.reset_last_sandbox()
}
\description{
Reset sandbox state (internal)
}
\keyword{internal}
