% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/snapshot.R
\name{serialize_value}
\alias{serialize_value}
\title{Serialize Value to Human-Readable Text}
\usage{
serialize_value(value, methods = NULL, use_class_defaults = TRUE)
}
\arguments{
\item{value}{The R object to serialize.}

\item{methods}{A function or a non-empty list of functions applied in order.
Defaults to \code{list(print = base::print, str = utils::str)}.}
}
\value{
A character vector with the text representation.
}
\description{
Converts an R object to a human-readable text representation for snapshots.
}
\keyword{internal}
